@@ -9,7 +9,7 @@ BEGIN {
     # set the version for version checking
     #$VERSION     = 1.00;
     # if using RCS/CVS, this may be preferred
-    #$VERSION = do { my @r = (q$Revision: 91 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
+    #$VERSION = do { my @r = (q$Revision: 153 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
     
     @ISA         = qw(Exporter);
     @EXPORT      = qw(); #(&func1 &func2 &func4);
@@ -32,7 +32,7 @@ use Data::Dumper;
 #controle in a hash: $correspondance{$HaploID}->{"case"} and
 #$correspondance{$HaploID}->{"controle"}
 
-sub ReadCorrespond 
+sub ReadCorrespondQuali
 {
     my($name_correspond) =shift;
     my($ligne, @tableau);
@@ -98,6 +98,50 @@ sub ReadCorrespond
     #}
     return(\%correspondance);
 }
+#Read the file correspond.txt and put haplotype ID... (to be continued)
+sub ReadCorrespondQuanti
+{
+    my($name_correspond) =shift;
+    my($ligne, @tableau);
+    my($correspondance);
+    open (CORRESP, '<', $name_correspond) 
+	or erreur("Unable to read file '$name_correspond': $!\n", 0);
+    my $numhaplo=0;
+    while ($ligne=<CORRESP>) {
+	chomp($ligne);
+	if ($ligne =~ /^\s*$/) {
+	    next;
+	}
+	# On peut mettre '#' ou ';' pour introduire une ligne de commentaire
+	my $di="#";
+	if ($ligne =~ /^\s*[$di;]/) {
+	    next;
+	}
+	@tableau=split(/\s+/, $ligne);
+	$numhaplo++;
+	my $id=shift @tableau;
+	if ($id !~ /^[a-zA-Z0-9]+$/) {
+	    ALTree::Utils::erreur("The haplotype name '$id' contains".
+				  "unauthorized characters\n".
+				  "in $name_correspond at".
+				  " line $.:\n$ligne\nPlease, check the syntax.\n",0);
+	}
+	
+	for(my $i=0; $i<=$#tableau; $i++) {
+	    $correspondance->{$id}->[$i]->[0]=$tableau[$i]; 
+	    $correspondance->{$id}->[$i]->[1]=$numhaplo; 
+	    # $numhaplo sert pour les anova 2 facteurs emboits (2eme facteur)
+	}
+    }
+    #my($clefs);
+    #DEBUG
+    #foreach my $clefs (keys %{$correspondance}) {
+	#for (my $i=0; $i<scalar (@{$correspondance->{$clefs}}); $i++) {
+	#    print STDERR "$clefs  ", $correspondance->{$clefs}->[$i]->[1], "\n";
+    #}
+#}
+    return($correspondance);
+}
 
 # return :
 # Hash of
@@ -162,6 +206,9 @@ sub ReadInputFile1
 				     $datatype, $ancetre);
     }
     $file{"nb_trees"}=$index;
+    if ($index == 0) {
+	erreur("No tree in file '$input_file'\nAborting.\n", 0);
+    }
     return (\%file);
 }
 
