@@ -10,7 +10,7 @@ BEGIN {
     # set the version for version checking
     #$VERSION     = 1.00;
     # if using RCS/CVS, this may be preferred
-    #$VERSION = do { my @r = (q$Revision: 68 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
+    #$VERSION = do { my @r = (q$Revision: 434 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
     
     @ISA         = qw(Exporter);
     @EXPORT      = qw(); #(&func1 &func2 &func4);
@@ -42,7 +42,7 @@ sub internal_error
 
     die("Internal error: $msg\n".
 	"Please, report this bug (with all is needed to reproduce it) to:\n".
-	"bardel\@vjf.inserm.fr\n");
+	"Claire.Bardel\@univ-lyon1.fr\n");
 }
 
 1;
